SystemOrganization addCategory: #ConfigurationOfEBNF!

Object subclass: #ConfigurationOfEBNF
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfEBNF'!

!ConfigurationOfEBNF class methodsFor: 'development support' stamp: 'cipt 7/2/2012 19:19'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfEBNF class methodsFor: 'private' stamp: 'cipt 7/2/2012 19:19'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfEBNF class methodsFor: 'private' stamp: 'cipt 7/2/2012 19:19'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfEBNF class methodsFor: 'private' stamp: 'cipt 7/2/2012 19:19'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfEBNF class methodsFor: 'metacello tool support' stamp: 'cipt 7/2/2012 19:19'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfEBNF class methodsFor: 'loading' stamp: 'cipt 7/2/2012 19:19'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfEBNF class methodsFor: 'loading' stamp: 'cipt 7/2/2012 19:19'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfEBNF class methodsFor: 'loading' stamp: 'cipt 7/2/2012 19:19'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfEBNF class methodsFor: 'accessing' stamp: 'cipt 7/2/2012 19:19'!
project

	^self new project! !

!ConfigurationOfEBNF class methodsFor: 'development support' stamp: 'cipt 7/2/2012 19:19'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfEBNF methodsFor: 'baselines' stamp: 'cipt 7/2/2012 19:19'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://ss3.gemstone.com/ss/EBNFParser'.
		spec 
			project: 'PetitParser' with: [
				spec
					className: 'ConfigurationOfPetitParser';
					versionString: #'stable';
					repository: 'http://source.lukas-renggli.ch/petit' ];
			project: 'VisiTrait' with: [
				spec
					className: 'ConfigurationOfVisiTrait';
					versionString: #'bleedingEdge';
					repository: 'http://ss3.gemstone.com/ss/VisiTrait' ].
		spec 
			package: 'EBNF-Parser' with: [
				spec requires: #('PetitParser' ). ];
			package: 'EBNF-AST-Traits' with: [
				spec requires: #('VisiTrait' ). ];
			package: 'EBNF-AST-Nodes';
			package: 'EBNF-Petit-Conversions';
			package: 'EBNF-Parser-Tests';
			package: 'EBNF-AST-Tests';
			package: 'EBNF-GeneratedParser';
			package: 'EBNF-GeneratedParser-Tests'.
		spec 
			group: 'default' with: #('Core' );
			group: 'Core' with: #('EBNF-Parser' 'EBNF-AST-Traits' 'EBNF-AST-Nodes' 'EBNF-Petit-Conversions' );
			group: 'Tests' with: #('EBNF-Parser-Tests' 'EBNF-AST-Tests' ). ].
! !

!ConfigurationOfEBNF methodsFor: 'symbolic versions' stamp: 'cipt 7/2/2012 19:19'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfEBNF methodsFor: 'accessing' stamp: 'cipt 7/2/2012 19:19'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfEBNF methodsFor: 'versions' stamp: 'cipt 7/2/2012 19:19'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'initial version'.
		spec author: 'cipt'.
		spec timestamp: '7/2/2012 19:19'.
		spec 
			project: 'PetitParser' with: #'stable';
			project: 'VisiTrait' with: '1.0'.
		spec 
			package: 'EBNF-Parser' with: 'EBNF-Parser';
			package: 'EBNF-AST-Traits' with: 'EBNF-AST-Traits';
			package: 'EBNF-AST-Nodes' with: 'EBNF-AST-Nodes';
			package: 'EBNF-Petit-Conversions' with: 'EBNF-Petit-Conversions';
			package: 'EBNF-Parser-Tests' with: 'EBNF-Parser-Tests';
			package: 'EBNF-AST-Tests' with: 'EBNF-AST-Tests';
			package: 'EBNF-GeneratedParser' with: 'EBNF-GeneratedParser';
			package: 'EBNF-GeneratedParser-Tests' with: 'EBNF-GeneratedParser-Tests'. ].
! !
